//
//  ARRegister.h
//  ARRegisterFrameworkTest
//
//  Created by Simon Bovet on 04.01.05.
//  Copyright 2005 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#define ARApplicationDidRegisteredNotification @"ARApplicationDidRegisteredNotification"

@interface ARRegisterManager : NSWindowController {
	NSMutableDictionary *mInfo;
	NSMutableDictionary *mPersistentInfo;
	NSMutableArray *mVersions;
	NSMutableArray *mSerialNumbers;
	NSMutableArray *mBlacklist;
	NSMutableDictionary *mExpiredSerialNumbers;
	NSDictionary *mExpirationInfo;
	id mDelegate;
	
	IBOutlet NSWindow *mBuyLicenseWindow;
	IBOutlet id mBuyLicenseTitleItem;
	IBOutlet id mBuyLicenseMessageItem;
	IBOutlet NSTableView *mVersionTableView;
	IBOutlet NSTextView *mVersionComment;
	
	IBOutlet NSWindow *mEnterSerialNumberWindow;
	IBOutlet id mEnterSerialNumberTitleItem;
	IBOutlet id mNameItem;
	IBOutlet id mCompanyItem;
	IBOutlet id mSerialNumberItem;
}

@end

@interface ARRegisterManager (Public)

+(id)sharedManager;

-(void)addVersionWithID:(NSString *)inID
	name:(NSString *)inName
	price:(NSString *)inPrice
	comment:(NSString *)inComment
	latest:(BOOL)inLatest
	equivalentToID:(NSString *)inEquivalentID
	eSellerID:(NSString *)ineSellerID
	SKUID:(NSString *)inSKUID
	previewID:(NSString *)inPreviewID
	eSelleratePrefix:(NSString *)ineSelleratePrefix
	expirable:(BOOL)inExpirable
	arizonaPrefix:(NSString *)inArizonaPrefix
	previousVersionIDs:(NSArray *)inPreviousVersionIDs;
-(void)addInvalidBlacklist:(NSString *)inList;
-(void)addHackedBlacklist:(NSString *)inList;

-(void)setDelegate:(id)inDelegate;

-(BOOL)hasRegisteredApplication;
-(BOOL)hasRegisteredVersionWithID:(NSString *)inID;

-(NSString *)registeredVersionID;
-(NSString *)registeredVersionName;
-(NSString *)registeredName;
-(NSString *)registeredCompany;
-(NSString *)registeredSerialNumber;
-(int)registeredNumberOfCopies;
-(NSString *)registrationShortMessage;

@end

@interface ARRegisterManager (PublicInterface)

-(void)displayStartupLicenseWindow:(id)inSender;
-(void)displayLicenseWindow:(id)inSender;

@end

@interface ARRegisterManager (Interface)

-(IBAction)stopModal:(id)inSender;
-(IBAction)confirmSerialNumber:(id)inSender;

@end

@interface ARRegisterManager (eSellerate)

-(BOOL)eSellerateInstallEngine;
-(BOOL)eSellerateBuyVersion:(id)inVersion;
-(BOOL)eSellerateIsValidSerialNumber:(NSString *)inSerialNumber name:(NSString *)inName expirationDate:(NSDate **)outExpirationDate;

@end

@interface ARRegisterManager (Arizona)

-(BOOL)validateSecurityKey:(NSString *)inKey withName:(NSString *)inName expirationDate:(NSDate **)outDate;

@end

@interface ARRegisterManager (Register)

-(BOOL)buyVersionWithID:(NSString *)inID;
-(BOOL)enterName:(NSString *)inName company:(NSString *)inCompany serialNumber:(NSString *)inSerialNumber;

@end

@interface ARRegisterManager (SerialNumbers)

-(void)loadData;
-(void)saveData;
-(void)removeSerialNumbers;
-(void)checkSerialNumbers;
-(void)recheckSerialNumbers;

-(void)didEnterValidName:(NSString *)inName company:(NSString *)inCompany serialNumber:(NSString *)inSerialNumber;

@end

@interface ARRegisterManager (Notifications)

-(void)serialNumberForVersionID:(NSString *)inID willExpireInDays:(int)inDaysRemaining;
-(void)serialNumberDidExpireForVersionID:(NSString *)inID;

@end

@interface ARRegisterManager (Blacklist)

-(void)loadBlacklist;
-(void)saveBlacklist;
-(void)addBlacklist:(NSString *)inList withLevel:(int)inLevel;
-(BOOL)blacklistContainsSerialNumber:(NSString *)inSerialNumber;

@end

@interface ARRegisterManager (Expiration)

-(void)addExpiredSerialNumber:(NSString *)inSerialNumber reason:(NSString *)inReason details:(NSString *)inDetails;

@end

@interface ARRegisterManager (PersistentInfo)

-(NSMutableDictionary *)persistentDictionaryForKey:(id)inKey;

@end

@interface NSString (ARRegisterManager)

-(NSString *)stringByRemovingAmbiguities;

@end

@protocol ARRegisterManagerDelegate

-(NSString *)titleForEnterSerialNumberWindow:(id)inSender;

@end
